@@ -423,8 +423,8 @@ func (s *Suite) Test_CheckLinesBuildlink3Mk__multiple_inclusion_wrong(c *check.C
 	CheckLinesBuildlink3Mk(mklines)
 
 	t.CheckOutputLines(
-		"WARN: buildlink3.mk:5: HS_X11_BUILDLINK3_MK is used but not defined.",
-		"WARN: buildlink3.mk:6: UNRELATED_BUILDLINK3_MK is defined but not used.",
+		"WARN: buildlink3.mk:5: Variable \"HS_X11_BUILDLINK3_MK\" is used but not defined.",
+		"WARN: buildlink3.mk:6: Variable \"UNRELATED_BUILDLINK3_MK\" is defined but not used.",
 		"WARN: buildlink3.mk:6: This line should consist of the following text: HS_X11_BUILDLINK3_MK:=")
 }
 
@@ -470,8 +470,8 @@ func (s *Suite) Test_CheckLinesBuildlink3Mk__invalid_dependency_patterns(c *chec
 	CheckLinesBuildlink3Mk(mklines)
 
 	t.CheckOutputLines(
-		"ERROR: buildlink3.mk:9: Invalid dependency pattern \"hs-X11!=1.6.1\".",
-		"ERROR: buildlink3.mk:10: Invalid dependency pattern \"hs-X11!=1.6.1.2nb2\".")
+		"ERROR: buildlink3.mk:9: Invalid package pattern \"hs-X11!=1.6.1\".",
+		"ERROR: buildlink3.mk:10: Invalid package pattern \"hs-X11!=1.6.1.2nb2\".")
 }
 
 func (s *Suite) Test_CheckLinesBuildlink3Mk__PKG_OPTIONS(c *check.C) {
@@ -750,7 +750,7 @@ func (s *Suite) Test_Buildlink3Checker_checkExpr__PKG_BUILD_OPTIONS(c *check.C)
 
 	t.CheckOutputLines(
 		"WARN: ~/category/package/buildlink3.mk:15: "+
-			"PKG_BUILD_OPTIONS is used but not defined.",
+			"Variable \"PKG_BUILD_OPTIONS\" is used but not defined.",
 		"ERROR: ~/category/package/buildlink3.mk:12: "+
 			"A buildlink3.mk file must only query its own PKG_BUILD_OPTIONS.package, "+
 			"not PKG_BUILD_OPTIONS.unrelated.",
@@ -805,9 +805,9 @@ func (s *Suite) Test_Buildlink3Checker_checkVarassign__dependencies_with_path(c
 	// Doing that would reveal that the ABI version should be higher than the API version.
 	t.CheckOutputLines(
 		"ERROR: ~/category/package/buildlink3.mk:12: "+
-			"Dependency pattern \"package>=1.0\" is followed by extra text \":../../category/package\".",
+			"Package pattern \"package>=1.0\" is followed by extra text \":../../category/package\".",
 		"ERROR: ~/category/package/buildlink3.mk:13: "+
-			"Dependency pattern \"package>=1.5\" is followed by extra text \":../../category/package\".")
+			"Package pattern \"package>=1.5\" is followed by extra text \":../../category/package\".")
 }
 
 func (s *Suite) Test_Buildlink3Checker_checkVarassign__abi_without_api(c *check.C) {
@@ -1172,13 +1172,13 @@ func (s *Suite) Test_LoadBuildlink3Data(c *check.C) {
 		id:        "package",
 		prefix:    "${PREFIX}",
 		pkgsrcdir: "../../category/package",
-		apiDepends: &DependencyPattern{
+		apiDepends: &PackagePattern{
 			Pkgbase: "package",
 			LowerOp: ">=",
 			Lower:   "0",
 		},
 		apiDependsLine: mklines.mklines[7],
-		abiDepends: &DependencyPattern{
+		abiDepends: &PackagePattern{
 			Pkgbase: "package",
 			LowerOp: ">=",
 			Lower:   "0.1",
