@@ -25,13 +25,13 @@ func (ck *MkAssignChecker) check() {
 // checkLeft checks everything to the left of the assignment operator.
 func (ck *MkAssignChecker) checkLeft() {
 	varname := ck.MkLine.Varname()
-	if G.Pkgsrc != nil && !ck.mayBeDefined(varname) {
-		ck.MkLine.Warnf("Variable names starting with an underscore (%s) are reserved for internal pkgsrc use.", varname)
-	}
-
 	if G.Pkgsrc == nil {
 		goto checkExpr
 	}
+
+	if !ck.mayBeDefined(varname) {
+		ck.MkLine.Warnf("Variable names starting with an underscore (%s) are reserved for internal pkgsrc use.", varname)
+	}
 	ck.checkLeftNotUsed()
 	ck.checkLeftOpsys()
 	ck.checkLeftDeprecated()
@@ -85,7 +85,7 @@ func (ck *MkAssignChecker) checkLeftNotUsed() {
 		return
 	}
 
-	ck.MkLine.Warnf("%s is defined but not used.", varname)
+	ck.MkLine.Warnf("Variable \"%s\" is defined but not used.", varname)
 	ck.MkLine.Explain(
 		"This might be a simple typo.",
 		"",
@@ -479,7 +479,10 @@ func (ck *MkAssignChecker) checkOpAppendOnly() {
 		break
 	default:
 		if hasSuffix(varbase, "_REQD") {
-			break
+			vartype := G.Pkgsrc.VariableType(ck.MkLines, varname)
+			if vartype != nil && vartype.IsList() == yes {
+				break
+			}
 		}
 		return
 	}
@@ -571,28 +574,26 @@ func (ck *MkAssignChecker) checkRightConfigureArgs() {
 	if !m {
 		return
 	}
-	gnuConfigure := G.Pkgsrc.File("mk/configure/gnu-configure.mk")
 
-	action := func(gnuMkline *MkLine) bool {
+	gnuConfigure := G.Pkgsrc.File("mk/configure/gnu-configure.mk")
+	gnuConfigureMk := LoadMk(gnuConfigure, pkg, MustSucceed|NotEmpty)
+	for _, gnuMkline := range gnuConfigureMk.mklines {
 		if !gnuMkline.IsVarassign() || gnuMkline.Varname() != "CONFIGURE_ARGS" {
-			return true
+			continue
 		}
 		m, gnuOpt := match1(gnuMkline.Value(), `^(--[\w-]+)=?`)
 		if !m || mkOpt != gnuOpt {
-			return true
+			continue
 		}
-		mkline.Warnf("The option %q is already handled by %q.",
-			mkOpt, mkline.Rel(gnuConfigure))
+		mkline.Warnf("The option %q is already handled by %s.",
+			mkOpt, mkline.RelMkLine(gnuMkline))
 		mkline.Explain(
 			"Packages should not specify this option directly,",
 			"as the pkgsrc infrastructure may override its value",
 			"based on other variables.",
-			"See gnu-configure.mk for further details.")
-		return false
+			"See mk/configure/gnu-configure.mk for further details.")
+		break
 	}
-
-	mklines := LoadMk(gnuConfigure, pkg, 0)
-	mklines.ForEachEnd(action, func(lastMkline *MkLine) {})
 }
 
 func (ck *MkAssignChecker) checkRightUseLanguages() {
@@ -633,7 +634,7 @@ func (ck *MkAssignChecker) checkMisc() {
 	varname := mkline.Varname()
 	value := mkline.Value()
 
-	if contains(value, "/etc/rc.d") && mkline.Varname() != "RPMIGNOREPATH" {
+	if G.Pkgsrc != nil && contains(value, "/etc/rc.d") && mkline.Varname() != "RPMIGNOREPATH" {
 		mkline.Warnf("Use the RCD_SCRIPTS mechanism to install rc.d scripts automatically to ${RCD_SCRIPTS_EXAMPLEDIR}.")
 	}
 
