@@ -277,7 +277,7 @@ func (s *Suite) Test_MkCondSimplifier_simplifyWord__undefined(c *check.C) {
 		".if ${UNDEFINED:Mpattern}",
 		".if ${UNDEFINED:Mpattern}",
 
-		"WARN: filename.mk:6: UNDEFINED is used but not defined.")
+		"WARN: filename.mk:6: Variable \"UNDEFINED\" is used but not defined.")
 }
 
 // Show how different kinds of ':M'-style patterns are replaced with simpler
@@ -407,18 +407,11 @@ func (s *Suite) Test_MkCondSimplifier_simplifyWord__patterns(c *check.C) {
 
 	// Matching for the empty pattern doesn't make sense,
 	// as the resulting string is always empty.
-	// Nevertheless, pkglint simplifies it.
-	// FIXME: This replacement does not preserve the behavior.
 	t.testBeforeAndAfterPrefs(
 		".if !empty(IN_SCOPE_DEFINED:M)",
-		".if ${IN_SCOPE_DEFINED} == \"\"",
+		".if !empty(IN_SCOPE_DEFINED:M)",
 
-		"NOTE: filename.mk:6: IN_SCOPE_DEFINED can be "+
-			"compared using the simpler "+"\"${IN_SCOPE_DEFINED} == \"\"\" "+
-			"instead of matching against \":M\".",
-		"AUTOFIX: filename.mk:6: "+
-			"Replacing \"!empty(IN_SCOPE_DEFINED:M)\" "+
-			"with \"${IN_SCOPE_DEFINED} == \\\"\\\"\".")
+		nil...)
 }
 
 // Show in which cases the ':N' modifier is replaced.
@@ -493,7 +486,7 @@ func (s *Suite) Test_MkCondSimplifier_simplifyWord__N(c *check.C) {
 		".if ${UNDEFINED:Nnegative-pattern}",
 		".if ${UNDEFINED:Nnegative-pattern}",
 
-		"WARN: filename.mk:6: UNDEFINED is used but not defined.")
+		"WARN: filename.mk:6: Variable \"UNDEFINED\" is used but not defined.")
 
 	t.testAfterPrefs(
 		".if !empty(LATER:Npattern)",
@@ -645,7 +638,7 @@ func (s *Suite) Test_MkCondSimplifier_simplifyWord__complex(c *check.C) {
 		".if ${PREFS_DEFINED:Mpattern} != ${OTHER}",
 		".if ${PREFS_DEFINED:Mpattern} != ${OTHER}",
 
-		"WARN: filename.mk:6: OTHER is used but not defined.")
+		"WARN: filename.mk:6: Variable \"OTHER\" is used but not defined.")
 
 	// The condition is also simplified if it doesn't use the '!empty'
 	// form but the implicit conversion to boolean.
@@ -799,23 +792,27 @@ func (s *Suite) Test_MkCondSimplifier_simplifyWord__defined_in_same_file(c *chec
 func (s *Suite) Test_MkCondSimplifier_simplifyWord__list_and_unknown(c *check.C) {
 	t := s.Init(c)
 
-	t.SetUpVarType("SINGLE_WORD", BtYesNo, NoVartypeOptions, nil...)
+	t.SetUpVarType("YES_NO", BtYesNo, NoVartypeOptions, nil...)
+	t.SetUpVarType("YES_NO_LIST", BtYesNo, List, nil...)
 	t.SetUpVarType("UNKNOWN", BtUnknown, NoVartypeOptions, nil...)
-	t.SetUpVarType("LIST_OF_WORDS", BtYesNo, List, nil...)
 	t.CreateFileLines("mk/bsd.prefs.mk",
 		MkCvsID)
 	t.Chdir("category/package")
 	mklines := t.NewMkLines("filename.mk",
 		MkCvsID,
-		"SINGLE_WORD=\tyes",
-		"LIST_OF_WORDS=\tyes",
+		"YES_NO=\t\tyes",
+		"YES_NO_LIST=\tyes",
 		"UNKNOWN=\tunknown",
 		"",
 		".include \"../../mk/bsd.prefs.mk\"",
 		"",
-		".if !empty(SINGLE_WORD:Myes)",
+		".if !empty(YES_NO:Myes)",
 		".endif",
-		".if !empty(LIST_OF_WORDS:Myes)",
+		".if !empty(YES_NO:tl:Myes)",
+		".endif",
+		".if !empty(YES_NO_LIST:Myes)",
+		".endif",
+		".if !empty(YES_NO_LIST:tl:Myes)",
 		".endif",
 		".if !empty(UNKNOWN:Myes)",
 		".endif")
@@ -824,14 +821,17 @@ func (s *Suite) Test_MkCondSimplifier_simplifyWord__list_and_unknown(c *check.C)
 
 	t.CheckOutputLines(
 		// FIXME: The preferred matching recipe is ':tl:Myes' now.
-		"WARN: filename.mk:8: SINGLE_WORD should be matched "+
+		"WARN: filename.mk:8: YES_NO should be matched "+
 			"against \"[yY][eE][sS]\" or \"[nN][oO]\", "+
 			"not \"yes\".",
-		"NOTE: filename.mk:8: SINGLE_WORD can be compared "+
-			"using the simpler \"${SINGLE_WORD} == yes\" "+
+		"NOTE: filename.mk:8: YES_NO can be compared "+
+			"using the simpler \"${YES_NO} == yes\" "+
+			"instead of matching against \":Myes\".",
+		"NOTE: filename.mk:10: YES_NO can be compared "+
+			"using the simpler \"${YES_NO:tl} == yes\" "+
 			"instead of matching against \":Myes\".",
 		// FIXME: The preferred matching recipe is ':tl:Myes' now.
-		"WARN: filename.mk:10: LIST_OF_WORDS should be matched "+
+		"WARN: filename.mk:12: YES_NO_LIST should be matched "+
 			"against \"[yY][eE][sS]\" or \"[nN][oO]\", "+
 			"not \"yes\".",
 	)
@@ -884,6 +884,22 @@ func (s *Suite) Test_MkCondSimplifier_simplifyYesNo(c *check.C) {
 
 		"WARN: filename.mk:6: VAR should be matched against "+
 			"\"[yY][eE][sS]\" or \"[nN][oO]\", not \"[Yy][Ee][s]\".")
+
+	// Repeating a character in a character list is redundant.
+	t.testAfterPrefs(
+		".if ${VAR:M[YY]}",
+		".if ${VAR:M[YY]}",
+
+		"WARN: filename.mk:6: VAR should be matched against "+
+			"\"[yY][eE][sS]\" or \"[nN][oO]\", not \"[YY]\".")
+
+	// Two lowercase characters in a character list are not case-insensitive.
+	t.testAfterPrefs(
+		".if ${VAR:M[ae]}",
+		".if ${VAR:M[ae]}",
+
+		"WARN: filename.mk:6: VAR should be matched against "+
+			"\"[yY][eE][sS]\" or \"[nN][oO]\", not \"[ae]\".")
 }
 
 func (s *Suite) Test_MkCondSimplifier_simplifyMatch(c *check.C) {
@@ -1031,7 +1047,7 @@ func (s *Suite) Test_MkCondSimplifier_isDefined(c *check.C) {
 		}
 	})
 	t.CheckOutputLines(
-		"WARN: filename.mk:3: UNDEFINED is used but not defined.")
+		"WARN: filename.mk:3: Variable \"UNDEFINED\" is used but not defined.")
 }
 
 func Test_MkCondSimplifier_mayMatchNumber(t *testing.T) {
