@@ -68,7 +68,7 @@ func (ck *MkExprChecker) checkUndefined() {
 	}
 
 	if ck.MkLines.once.FirstTimeSlice("used but not defined", varname) {
-		ck.MkLine.Warnf("%s is used but not defined.", varname)
+		ck.MkLine.Warnf("Variable \"%s\" is used but not defined.", varname)
 	}
 }
 
@@ -781,7 +781,7 @@ func (ck *MkExprChecker) warnRedundantModifierQ(mod string) {
 		"\t* user and group names",
 		"\t* tool names and tool paths",
 		"\t* variable names",
-		"\t* package names (but not dependency patterns like pkg>=1.2)")
+		"\t* package names (but not package patterns like pkg>=1.2)")
 	fix.Replace(bad, good)
 	fix.Apply()
 }
