@@ -22,7 +22,7 @@ func (s *Suite) Test_MkExprChecker_Check(c *check.C) {
 	mklines.Check()
 
 	t.CheckOutputLines(
-		"WARN: filename.mk:3: UNKNOWN is used but not defined.")
+		"WARN: filename.mk:3: Variable \"UNKNOWN\" is used but not defined.")
 }
 
 // The ${VARNAME:=suffix} expression should only be used with lists.
@@ -113,7 +113,7 @@ func (s *Suite) Test_MkExprChecker_Check__defined_in_infrastructure(c *check.C)
 	mklines.Check()
 
 	t.CheckOutputLines(
-		"WARN: ~/category/package/module.mk:3: UNDEFINED is used but not defined.")
+		"WARN: ~/category/package/module.mk:3: Variable \"UNDEFINED\" is used but not defined.")
 }
 
 func (s *Suite) Test_MkExprChecker_Check__build_defs(c *check.C) {
@@ -223,7 +223,7 @@ func (s *Suite) Test_MkExprChecker_checkUndefined(c *check.C) {
 	mklines.Check()
 
 	t.CheckOutputLines(
-		"WARN: filename.mk:4: UNKNOWN is used but not defined.")
+		"WARN: filename.mk:4: Variable \"UNKNOWN\" is used but not defined.")
 }
 
 // PR 46570, item "15. net/uucp/Makefile has a make loop"
@@ -245,7 +245,7 @@ func (s *Suite) Test_MkExprChecker_checkUndefined__indirect_variables(c *check.C
 	//
 	// It does warn about simple variable names though, like ${var} in this example.
 	t.CheckOutputLines(
-		"WARN: net/uucp/Makefile:2: var is used but not defined.")
+		"WARN: net/uucp/Makefile:2: Variable \"var\" is used but not defined.")
 }
 
 // Documented variables are declared as both defined and used since, as
@@ -313,7 +313,7 @@ func (s *Suite) Test_MkExprChecker_checkModifiersSuffix(c *check.C) {
 		"WARN: file.mk:2: The text \":Q\" looks like a modifier but isn't.",
 		"WARN: file.mk:2: The :from=to modifier should only be used with lists, not with HOMEPAGE.",
 		"WARN: file.mk:2: The text \":Q\" looks like a modifier but isn't.",
-		"WARN: file.mk:4: BIN_PROGRAMS is used but not defined.")
+		"WARN: file.mk:4: Variable \"BIN_PROGRAMS\" is used but not defined.")
 }
 
 func (s *Suite) Test_MkExprChecker_checkModifiersRange(c *check.C) {
@@ -455,6 +455,8 @@ func (s *Suite) Test_MkExprChecker_checkVarnameBuildlink(c *check.C) {
 		"CONFIGURE_ARGS+=\t--with-package=${BUILDLINK_PREFIX.package}",
 		"CONFIGURE_ARGS+=\t--with-package=${BUILDLINK_PREFIX.${PKGBASE}}",
 		"",
+		".include \"options.mk\"",
+		"",
 		".include \"../../category/library/buildlink3.mk\"")
 	t.CreateFileLines("category/package/options.mk",
 		MkCvsID,
@@ -480,9 +482,9 @@ func (s *Suite) Test_MkExprChecker_checkVarnameBuildlink(c *check.C) {
 	t.CheckOutputLines(
 		"WARN: Makefile:20: Buildlink identifier \"library\" is not known in this package.",
 		"WARN: Makefile:22: Buildlink identifier \"package\" is not known in this package.",
-		"WARN: buildlink3.mk:12: BL3 is defined but not used.",
+		"WARN: buildlink3.mk:12: Variable \"BL3\" is defined but not used.",
 		"WARN: buildlink3.mk:12: Buildlink identifier \"unknown-bl3\" is not known in this package.",
-		"WARN: builtin.mk:2: BUILTIN is defined but not used.",
+		"WARN: builtin.mk:2: Variable \"BUILTIN\" is defined but not used.",
 		"WARN: builtin.mk:2: Buildlink identifier \"unknown-builtin\" is not known in this package.",
 		"WARN: options.mk:7: Buildlink identifier \"package\" is not known in this package.")
 }
@@ -969,7 +971,7 @@ func (s *Suite) Test_MkExprChecker_warnPermissions__not_directly_and_no_alternat
 	t.CheckEquals(toolDependsType.AlternativeFiles(aclpUseLoadtime), "")
 
 	apiDependsType := G.Pkgsrc.VariableType(nil, "BUILDLINK_API_DEPENDS.*")
-	t.CheckEquals(apiDependsType.String(), "DependencyPattern (list, package-settable)")
+	t.CheckEquals(apiDependsType.String(), "PackagePattern (list, package-settable)")
 	t.CheckEquals(apiDependsType.AlternativeFiles(aclpUse), "")
 	t.CheckEquals(apiDependsType.AlternativeFiles(aclpUseLoadtime), "buildlink3.mk or builtin.mk only")
 
@@ -1142,7 +1144,7 @@ func (s *Suite) Test_MkExprChecker_warnToolLoadTime(c *check.C) {
 			"bsd.prefs.mk has to be included before.",
 		"WARN: Makefile:6: Variable names starting with an underscore "+
 			"(_TOOLS_VARNAME.mk-tool) are reserved for internal pkgsrc use.",
-		"WARN: Makefile:6: _TOOLS_VARNAME.mk-tool is defined but not used.")
+		"WARN: Makefile:6: Variable \"_TOOLS_VARNAME.mk-tool\" is defined but not used.")
 }
 
 // This somewhat unrealistic case demonstrates how there can be a tool in a
@@ -1167,8 +1169,8 @@ func (s *Suite) Test_MkExprChecker_warnToolLoadTime__local_tool(c *check.C) {
 
 	t.CheckOutputLines(
 		"WARN: ~/category/package/Makefile:5: Variable names starting with an underscore (_TOOLS_VARNAME.mk-tool) are reserved for internal pkgsrc use.",
-		"WARN: ~/category/package/Makefile:5: _TOOLS_VARNAME.mk-tool is defined but not used.",
-		"WARN: ~/category/package/Makefile:7: TOOL_OUTPUT is defined but not used.",
+		"WARN: ~/category/package/Makefile:5: Variable \"_TOOLS_VARNAME.mk-tool\" is defined but not used.",
+		"WARN: ~/category/package/Makefile:7: Variable \"TOOL_OUTPUT\" is defined but not used.",
 		"WARN: ~/category/package/Makefile:7: The tool ${MK_TOOL} cannot be used at load time.")
 }
 
@@ -1293,7 +1295,7 @@ func (s *Suite) Test_MkExprChecker_checkQuoting__mstar(c *check.C) {
 
 	t.CheckOutputLines(
 		"WARN: ~/options.mk:2: Use ${CFLAGS:M*:Q} instead of ${CFLAGS:Q}.",
-		"WARN: ~/options.mk:4: ADA_FLAGS is used but not defined.",
+		"WARN: ~/options.mk:4: Variable \"ADA_FLAGS\" is used but not defined.",
 		"WARN: ~/options.mk:6: Use ${CFLAGS:M*:Q} instead of ${CFLAGS:Q}.")
 }
 
@@ -1560,7 +1562,7 @@ func (s *Suite) Test_MkExprChecker_checkDeprecated(c *check.C) {
 	mklines.Check()
 
 	t.CheckOutputLines(
-		"WARN: filename.mk:3: USE_CROSSBASE is used but not defined.",
+		"WARN: filename.mk:3: Variable \"USE_CROSSBASE\" is used but not defined.",
 		"WARN: filename.mk:3: Use of \"USE_CROSSBASE\" is deprecated. "+
 			"Has been removed.")
 }
