@@ -11,7 +11,7 @@ import (
 // MkLine is a line from a makefile fragment.
 // There are several types of lines.
 // The most common types in pkgsrc are variable assignments,
-// shell commands and directives like .if and .for.
+// shell commands, and directives like .if and .for.
 // The line types can be distinguished by IsVarassign,
 // IsDirective and so on.
 type MkLine struct {
@@ -22,7 +22,8 @@ type MkLine struct {
 	// One of the following mkLine* types.
 	//
 	// For the larger of these types, a pointer is used instead of a direct
-	// struct because of https://github.com/golang/go/issues/28045.
+	// struct because of https://github.com/golang/go/issues/28045;
+	// last checked against go1.23.1 in January 2025.
 	data interface{}
 }
 
@@ -280,7 +281,8 @@ func (mkline *MkLine) FirstLineContainsValue() bool {
 	// Parsing the continuation marker as variable value is cheating but works well.
 	text := mkline.raw[0].Orig()
 	parser := NewMkLineParser()
-	splitResult := parser.split(nil, text, true)
+	splitResult := parser.split(text, true)
+	splitResult.tokens = parser.tokenize(splitResult.main, nil)
 	_, a := parser.matchVarassign(mkline.Line, text, &splitResult)
 	return a.value != "\\"
 }
@@ -844,63 +846,13 @@ func (mkline *MkLine) VariableNeedsQuoting(mklines *MkLines, expr *MkExpr, varty
 
 // ForEachUsed calls the action for each variable that is used in the line.
 func (mkline *MkLine) ForEachUsed(action func(expr *MkExpr, time EctxTime)) {
-	switch {
-
-	case mkline.IsVarassign():
-		mkline.ForEachUsedText(mkline.Varname(), EctxLoadTime, action)
-		mkline.ForEachUsedText(mkline.Value(), mkline.Op().Time(), action)
-
-	case mkline.IsDirective():
-		mkline.forEachUsedDirective(action)
-
-	case mkline.IsShellCommand():
-		mkline.ForEachUsedText(mkline.ShellCommand(), EctxRunTime, action)
-
-	case mkline.IsDependency():
-		mkline.ForEachUsedText(mkline.Targets(), EctxLoadTime, action)
-		mkline.ForEachUsedText(mkline.Sources(), EctxLoadTime, action)
-
-	case mkline.IsInclude():
-		mkline.ForEachUsedText(mkline.IncludedFile().String(), EctxLoadTime, action)
-	}
-}
-
-func (mkline *MkLine) forEachUsedDirective(action func(expr *MkExpr, time EctxTime)) {
-	switch mkline.Directive() {
-	case "error", "for", "info", "warning":
-		mkline.ForEachUsedText(mkline.Args(), EctxLoadTime, action)
-	case "if", "elif":
-		if cond := mkline.Cond(); cond != nil {
-			cond.Walk(&MkCondCallback{
-				Expr: func(expr *MkExpr) {
-					mkline.ForEachUsedExpr(expr, EctxLoadTime, action)
-				}})
-		}
-	}
+	walker := NewMkWalker(action)
+	walker.WalkLine(mkline)
 }
 
 func (mkline *MkLine) ForEachUsedText(text string, time EctxTime, action func(expr *MkExpr, time EctxTime)) {
-	if !contains(text, "$") {
-		return
-	}
-
-	tokens, _ := NewMkLexer(text, nil).MkTokens()
-	for _, token := range tokens {
-		if token.Expr != nil {
-			mkline.ForEachUsedExpr(token.Expr, time, action)
-		}
-	}
-}
-
-func (mkline *MkLine) ForEachUsedExpr(expr *MkExpr, time EctxTime, action func(expr *MkExpr, time EctxTime)) {
-	varname := expr.varname
-	if !expr.IsExpression() {
-		action(expr, time)
-	}
-	mkline.ForEachUsedText(varname, time, action)
-	for _, mod := range expr.modifiers {
-		mkline.ForEachUsedText(mod.String(), time, action)
-	}
+	walker := NewMkWalker(action)
+	walker.WalkText(text, time)
 }
 
 // UnquoteShell removes one level of double and single quotes,
@@ -1267,7 +1219,7 @@ func (ind *Indentation) TrackBefore(mkline *MkLine) {
 
 	directive := mkline.Directive()
 	switch directive {
-	case "for", "if", "ifdef", "ifndef":
+	case "for", "if", "ifdef", "ifndef", "ifmake", "ifnmake":
 		guard := mkline == ind.guardLine || isBuildlink3Guard(mkline)
 		ind.Push(mkline, ind.Depth(directive), mkline.Args(), guard)
 	}
@@ -1380,6 +1332,9 @@ func MatchMkInclude(text string) (m bool, indentation, directive string, filenam
 	if directive == "" {
 		directive = lexer.NextString("sinclude")
 	}
+	if directive == "" {
+		directive = lexer.NextString("-include")
+	}
 	if directive == "" {
 		return false, "", "", ""
 	}
