@@ -33,11 +33,22 @@ func (s *Suite) Test_MkLineParser_Parse__infrastructure(c *check.C) {
 	mklines.Check()
 
 	t.CheckOutputLines(
-		"WARN: infra.mk:2: USE_BUILTIN.${_pkg_:S/^-//} is defined but not used.",
-		"WARN: infra.mk:2: _pkg_ is used but not defined.",
+		"WARN: infra.mk:2: Variable \"USE_BUILTIN.${_pkg_:S/^-//}\" is defined but not used.",
+		"WARN: infra.mk:2: Variable \"_pkg_\" is used but not defined.",
 		"ERROR: infra.mk:5: \".export\" requires arguments.",
-		"NOTE: infra.mk:2: This variable value should be aligned to column 41 instead of 39.",
-		"ERROR: infra.mk:10: Unmatched .endif.")
+		"NOTE: infra.mk:2: This variable value should be aligned to column 41 instead of 39.")
+}
+
+func (s *Suite) Test_MkLineParser_Parse__condition_empty(c *check.C) {
+	t := s.Init(c)
+
+	_ = t.NewMkLines("filename.mk",
+		MkCvsID,
+		".if empty(${_TOOLS_DEPMETHOD.${_t_}}:C/\\:.*$//:M${_dep_test})",
+		".endif")
+
+	// The "$/" is not an expression, it's the end of a modifier part.
+	t.CheckOutputEmpty()
 }
 
 // In variable assignments, a plain '#' introduces a line comment, unless
@@ -60,7 +71,8 @@ func (s *Suite) Test_MkLineParser_Parse__comment_or_not(c *check.C) {
 
 	t.CheckEquals(mklineCommandUnescaped.IsComment(), true)
 	t.CheckEquals(mklineCommandUnescaped.Comment(), " $ sha1 patches/patch-ac")
-	t.CheckOutputEmpty() // No warning about parsing the lonely dollar sign.
+	t.CheckOutputLines(
+		"WARN: filename.mk:1: Expression \"$ \" has unusual single-character variable name \" \".")
 
 	mklineVarassignUnescaped := t.NewMkLine("filename.mk", 1, "SED_CMD=\t's,#,hash,'")
 
@@ -87,6 +99,26 @@ func (s *Suite) Test_MkLineParser_Parse__commented_lines(c *check.C) {
 	test("\t\t# the comment")
 }
 
+func (s *Suite) Test_MkLineParser_Parse__invalid_lines(c *check.C) {
+	t := s.Init(c)
+
+	_ = t.NewMkLines("filename.mk",
+		MkCvsID,
+		"",
+		"invalid line",
+		"<<<<<<<< merge conflict",
+		">>>>>>>> merge conflict",
+		"\xa0 badly encoded non-breaking space",
+		"\x00 embedded null byte")
+
+	t.CheckOutputLines(
+		"ERROR: filename.mk:3: Unknown makefile line format: \"invalid line\".",
+		"ERROR: filename.mk:4: Unknown makefile line format: \"<<<<<<<< merge conflict\".",
+		"ERROR: filename.mk:5: Unknown makefile line format: \">>>>>>>> merge conflict\".",
+		"ERROR: filename.mk:6: Unknown makefile line format: \"\\xa0 badly encoded non-breaking space\".",
+		"ERROR: filename.mk:7: Unknown makefile line format: \"\\x00 embedded null byte\".")
+}
+
 func (s *Suite) Test_MkLineParser_parseVarassign(c *check.C) {
 	t := s.Init(c)
 
@@ -219,7 +251,8 @@ func (s *Suite) Test_MkLineParser_matchVarassign(c *check.C) {
 		_ = t.Output()
 
 		parser := NewMkLineParser()
-		splitResult := parser.split(nil, text, true)
+		splitResult := parser.split(text, true)
+		splitResult.tokens = parser.tokenize(splitResult.main, nil)
 		m, actual := parser.matchVarassign(line, text, &splitResult)
 
 		assert(m)
@@ -251,7 +284,8 @@ func (s *Suite) Test_MkLineParser_matchVarassign(c *check.C) {
 	testInvalid := func(text string, diagnostics ...string) {
 		line := t.NewLine("filename.mk", 123, text)
 		parser := NewMkLineParser()
-		splitResult := parser.split(nil, text, true)
+		splitResult := parser.split(text, true)
+		splitResult.tokens = parser.tokenize(splitResult.main, nil)
 		m, _ := parser.matchVarassign(line, text, &splitResult)
 		if m {
 			c.Errorf("Text %q matches variable assignment but shouldn't.", text)
@@ -533,7 +567,8 @@ func (s *Suite) Test_MkLineParser_parseDirective(c *check.C) {
 	test := func(input, expectedIndent, expectedDirective, expectedArgs, expectedComment string, diagnostics ...string) {
 		line := t.NewLine("filename.mk", 123, input)
 		parser := NewMkLineParser()
-		splitResult := parser.split(line, input, true)
+		splitResult := parser.split(input, true)
+		splitResult.tokens = parser.tokenize(splitResult.main, line)
 		mkline := parser.parseDirective(line, splitResult)
 		if !t.CheckNotNil(mkline) {
 			return
@@ -592,6 +627,18 @@ func (s *Suite) Test_MkLineParser_parseInclude(c *check.C) {
 	t.CheckEquals(mkline.IsSysinclude(), false)
 }
 
+func (s *Suite) Test_MkLineParser_parseInclude__dash_include(c *check.C) {
+	t := s.Init(c)
+
+	line := t.NewLine("filename.mk", 123, ".-include\t\"${.PARSEDIR}/defs.mk\"")
+	p := NewMkLineParser()
+
+	mkline := p.Parse(line)
+
+	t.CheckEquals(mkline.IsInclude(), true)
+	t.CheckEquals(mkline.IncludedFile(), NewRelPathString("${.PARSEDIR}/defs.mk"))
+}
+
 func (s *Suite) Test_MkLineParser_parseSysinclude(c *check.C) {
 	t := s.Init(c)
 
@@ -629,23 +676,6 @@ func (s *Suite) Test_MkLineParser_parseDependency__space(c *check.C) {
 		"NOTE: test.mk:101: Space before colon in dependency line.")
 }
 
-func (s *Suite) Test_MkLineParser_parseMergeConflict(c *check.C) {
-	t := s.Init(c)
-
-	mkline := t.NewMkLine("test.mk", 101,
-		"<<<<<<<<<<<<<<<<<")
-
-	// Merge conflicts are of neither type.
-	t.CheckEquals(mkline.IsVarassign(), false)
-	t.CheckEquals(mkline.IsDirective(), false)
-	t.CheckEquals(mkline.IsInclude(), false)
-	t.CheckEquals(mkline.IsEmpty(), false)
-	t.CheckEquals(mkline.IsComment(), false)
-	t.CheckEquals(mkline.IsDependency(), false)
-	t.CheckEquals(mkline.IsShellCommand(), false)
-	t.CheckEquals(mkline.IsSysinclude(), false)
-}
-
 func (s *Suite) Test_MkLineParser_split(c *check.C) {
 	t := s.Init(c)
 	b := NewMkTokenBuilder()
@@ -657,7 +687,9 @@ func (s *Suite) Test_MkLineParser_split(c *check.C) {
 
 	test := func(text string, expected mkLineSplitResult, diagnostics ...string) {
 		line := t.NewLine("filename.mk", 123, text)
-		actual := NewMkLineParser().split(line, text, true)
+		parser := NewMkLineParser()
+		actual := parser.split(text, true)
+		actual.tokens = parser.tokenize(actual.main, line)
 
 		t.CheckOutput(diagnostics)
 		t.CheckDeepEquals([]interface{}{text, actual}, []interface{}{text, expected})
@@ -879,22 +911,17 @@ func (s *Suite) Test_MkLineParser_split(c *check.C) {
 		},
 		"WARN: filename.mk:123: Missing closing \"}\" for \"UNCLOSED\".")
 
-	// Even in case of parse errors, the space before the comment is parsed
-	// correctly.
 	test("text before ${UNCLOSED # comment",
 		mkLineSplitResult{
 			main: "text before ${UNCLOSED",
 			tokens: tokens(
 				text("text before "),
-				// It's a bit inconsistent that the varname includes the space
-				// but the text doesn't; anyway, it's an edge case.
-				exprText("${UNCLOSED", "UNCLOSED ")),
+				exprText("${UNCLOSED", "UNCLOSED")),
 			spaceBeforeComment: " ",
 			hasComment:         true,
 			comment:            " comment",
 		},
-		"WARN: filename.mk:123: Missing closing \"}\" for \"UNCLOSED \".",
-		"WARN: filename.mk:123: Invalid part \" \" after variable name \"UNCLOSED\".")
+		"WARN: filename.mk:123: Missing closing \"}\" for \"UNCLOSED\".")
 
 	// The dollar-space refers to a normal Make variable named " ".
 	// The lonely dollar at the very end refers to the variable named "",
@@ -912,7 +939,8 @@ func (s *Suite) Test_MkLineParser_split(c *check.C) {
 				exprText("$ " /* instead of "${ }" */, " "),
 				text("character "),
 				text("$")),
-		})
+		},
+		"WARN: filename.mk:123: Expression \"$ \" has unusual single-character variable name \" \".")
 
 	// The character [ prevents the following # from starting a comment, even
 	// outside variable modifiers.
@@ -932,9 +960,11 @@ func (s *Suite) Test_MkLineParser_split(c *check.C) {
 			comment:    "comment",
 		})
 
-	// At this stage, MkLine.split doesn't know that empty(...) takes
-	// an expression. Instead, it just sees ordinary characters and
-	// other expressions.
+	// MkLine.split doesn't know that empty(...) takes an expression.
+	// Instead, it just sees ordinary characters and other expressions.
+	//
+	// Thus, Mkline.split cannot be used for splitting directive lines,
+	// it can only be used on strings handled by bmake's Var_Subst.
 	test(".if empty(${VAR.${tool}}:C/\\:.*$//:M${pattern})",
 		mkLineSplitResult{
 			main: ".if empty(${VAR.${tool}}:C/\\:.*$//:M${pattern})",
@@ -942,11 +972,12 @@ func (s *Suite) Test_MkLineParser_split(c *check.C) {
 				text(".if empty("),
 				expr("VAR.${tool}"),
 				text(":C/\\:.*"),
-				text("$"),
-				text("//:M"),
+				exprText("$/", "/"),
+				text("/:M"),
 				expr("pattern"),
 				text(")")),
-		})
+		},
+		"WARN: filename.mk:123: Expression \"$/\" has unusual single-character variable name \"/\".")
 
 	test("   # comment after spaces",
 		mkLineSplitResult{
@@ -982,7 +1013,9 @@ func (s *Suite) Test_MkLineParser_split__preserve_comment(c *check.C) {
 
 	test := func(text string, expected mkLineSplitResult, diagnostics ...string) {
 		line := t.NewLine("filename.mk", 123, text)
-		actual := NewMkLineParser().split(line, text, false)
+		parser := NewMkLineParser()
+		actual := parser.split(text, false)
+		actual.tokens = parser.tokenize(actual.main, line)
 
 		t.CheckDeepEquals(actual, expected)
 		t.CheckOutput(diagnostics)
@@ -1035,7 +1068,9 @@ func (s *Suite) Test_MkLineParser_split__unclosed_expr(c *check.C) {
 	test := func(text string, expected mkLineSplitResult, diagnostics ...string) {
 		line := t.NewLine("filename.mk", 123, text)
 
-		splitResult := NewMkLineParser().split(line, text, true)
+		parser := NewMkLineParser()
+		splitResult := parser.split(text, true)
+		splitResult.tokens = parser.tokenize(splitResult.main, line)
 
 		t.CheckDeepEquals(splitResult, expected)
 		t.CheckOutput(diagnostics)
