@@ -306,41 +306,6 @@ func (s *Suite) Test_Pkglint_Main__realistic(c *check.C) {
 	}
 }
 
-func (s *Suite) Test_Pkglint_Main__profiling(c *check.C) {
-	t := s.Init(c)
-
-	t.SetUpPkgsrc()
-	t.Chdir(".")
-
-	t.Main("--profiling")
-
-	// Pkglint always writes the profiling data into the current directory.
-	// TODO: Make the location of the profiling log a mandatory parameter.
-	t.CheckEquals(NewCurrPath("pkglint.pprof").IsFile(), true)
-
-	err := os.Remove("pkglint.pprof")
-	t.CheckNil(err)
-
-	// Everything but the first few lines of output is not easily testable
-	// or not interesting enough, since that info includes the exact timing
-	// that the top time-consuming regular expressions took.
-	firstOutput := strings.Split(t.Output(), "\n")[0]
-	t.CheckEquals(firstOutput, "ERROR: Makefile: Cannot be read.")
-}
-
-func (s *Suite) Test_Pkglint_Main__profiling_error(c *check.C) {
-	t := s.Init(c)
-
-	t.Chdir(".")
-	t.CreateFileLines("pkglint.pprof/file")
-
-	exitcode := t.Main("--profiling")
-
-	t.CheckEquals(exitcode, 1)
-	t.CheckOutputMatches(
-		`ERROR: pkglint\.pprof: Cannot create profiling file: open pkglint\.pprof: .*`)
-}
-
 // The option -Wall does not imply -Werror.
 func (s *Suite) Test_Pkglint_Main__Wall(c *check.C) {
 	t := s.Init(c)
@@ -353,7 +318,7 @@ func (s *Suite) Test_Pkglint_Main__Wall(c *check.C) {
 
 	t.CheckEquals(exitcode, 0)
 	t.CheckOutputLines(
-		"WARN: Makefile:20: UNUSED is defined but not used.",
+		"WARN: Makefile:20: Variable \"UNUSED\" is defined but not used.",
 		"1 warning found.",
 		"(Run \"pkglint -e -Wall\" to show explanations.)")
 }
@@ -382,7 +347,7 @@ func (s *Suite) Test_Pkglint_Main__Werror_warning(c *check.C) {
 
 	t.CheckEquals(exitcode, 1)
 	t.CheckOutputLines(
-		"WARN: Makefile:20: UNUSED is defined but not used.",
+		"WARN: Makefile:20: Variable \"UNUSED\" is defined but not used.",
 		"1 warning found.",
 		"(Run \"pkglint -e -Werror\" to show explanations.)")
 }
@@ -685,7 +650,8 @@ func (s *Suite) Test_Pkglint_checkdirPackage__filename_with_variable(c *check.C)
 	pkg := t.SetUpPackage("category/package",
 		".include \"../../mk/bsd.prefs.mk\"",
 		"",
-		"RUBY_VERSIONS_ACCEPTED=\t22 24 25", // As of 2018.
+		"# Needs a rationale.",
+		"RUBY_VERSIONS_ACCEPTED=\t31 32 33 34", // As of 2025.
 		".for rv in ${RUBY_VERSIONS_ACCEPTED}",
 		"RUBY_VER?=\t\t${rv}",
 		".endfor",
@@ -696,18 +662,20 @@ func (s *Suite) Test_Pkglint_checkdirPackage__filename_with_variable(c *check.C)
 	t.FinishSetUp()
 
 	// As of January 2019, pkglint cannot resolve the location of DISTINFO_FILE completely
-	// because the variable \"rv\" comes from a .for loop.
+	// because the variable "rv" comes from a .for loop.
 	//
 	// TODO: iterate over variables in simple .for loops like the above.
 	// TODO: when implementing the above, take care of deeply nested loops (42.zip).
 	G.Check(pkg)
 
-	t.CheckOutputEmpty()
+	t.CheckOutputLines(
+		"WARN: ~/category/package/Makefile:24: RUBY_VERSIONS_ACCEPTED should not be used at load time in any file.")
 
 	// Just for code coverage.
 	t.DisableTracing()
 	G.Check(pkg)
-	t.CheckOutputEmpty()
+	t.CheckOutputLines(
+		"WARN: ~/category/package/Makefile:24: RUBY_VERSIONS_ACCEPTED should not be used at load time in any file.")
 }
 
 func (s *Suite) Test_Pkglint_checkdirPackage__ALTERNATIVES(c *check.C) {
@@ -1160,11 +1128,7 @@ func (s *Suite) Test_Pkglint_checkReg__readme_and_todo(c *check.C) {
 
 	t.CheckOutputLines(
 		"ERROR: category/package/TODO: Packages in main pkgsrc must not have a TODO file.",
-		"WARN: wip/package/COMMIT_MSG: Every work-in-progress "+
-			"package should have a COMMIT_MSG file.",
-		"1 error and 1 warning found.",
-		"(Run \"pkglint -e category/package wip/package\" "+
-			"to show explanations.)",
+		"1 error found.",
 	)
 
 	t.Main("--import", "category/package", "wip/package")
@@ -1172,11 +1136,7 @@ func (s *Suite) Test_Pkglint_checkReg__readme_and_todo(c *check.C) {
 	t.CheckOutputLines(
 		"ERROR: category/package/TODO: Packages in main pkgsrc must not have a TODO file.",
 		"ERROR: wip/package/TODO: Must be cleaned up before committing the package.",
-		"WARN: wip/package/COMMIT_MSG: Every work-in-progress "+
-			"package should have a COMMIT_MSG file.",
-		"2 errors and 1 warning found.",
-		"(Run \"pkglint -e --import category/package wip/package\" "+
-			"to show explanations.)",
+		"2 errors found.",
 	)
 }
 
