@@ -212,6 +212,13 @@ func replaceOnce(s, from, to string) (ok bool, replaced string) {
 	return false, s
 }
 
+func abbreviate(s string) string {
+	if len(s) <= 200 {
+		return s
+	}
+	return s[:10] + "[...]" + s[len(s)-10:]
+}
+
 func isHspace(ch byte) bool {
 	return ch == ' ' || ch == '\t'
 }
@@ -962,7 +969,8 @@ func joinSkipEmpty(sep string, elements ...string) string {
 	return strings.Join(nonempty, sep)
 }
 
-// joinCambridge returns "first, second conn third".
+// joinCambridge returns "first, second conn third",
+// with no comma before the connector.
 // It is used when each element is a single word.
 // Empty elements are ignored completely.
 func joinCambridge(conn string, elements ...string) string {
@@ -984,7 +992,8 @@ func joinCambridge(conn string, elements ...string) string {
 	return strings.Join(parts, "")
 }
 
-// joinOxford returns "first, second, conn third".
+// joinOxford returns "first, second, conn third",
+// with a comma before the connector.
 // It is used when each element may consist of multiple words.
 // Empty elements are ignored completely.
 func joinOxford(conn string, elements ...string) string {
