@@ -1,7 +1,6 @@
 package pkglint
 
 import (
-	"github.com/rillig/pkglint/v23/pkgver"
 	"github.com/rillig/pkglint/v23/regex"
 	"github.com/rillig/pkglint/v23/textproc"
 	"path"
@@ -299,168 +298,6 @@ func (cv *VartypeCheck) ConfFiles() {
 	}
 }
 
-func (cv *VartypeCheck) DependencyPattern() {
-	value := cv.Value
-	valueNoVar := cv.ValueNoVar
-
-	if contains(valueNoVar, "{") {
-		switch {
-		case !hasBalancedBraces(value):
-			cv.Errorf("Dependency pattern %q must have balanced braces.", value)
-			return
-		default:
-			mainValue, nbPart := value, ""
-			if hasSuffix(value, "{,nb*}") {
-				mainValue, nbPart = value[:len(value)-6], value[len(value)-6:]
-			} else if hasSuffix(value, "{,nb[0-9]*}") {
-				mainValue, nbPart = value[:len(value)-11], value[len(value)-11:]
-			}
-
-			if contains(cv.MkLine.WithoutMakeVariables(mainValue), "{") {
-				if m, expr := match1(mainValue, `(\{[^{]*\bnb\b.*?})`); m {
-					cv.Warnf("The nb version part should have the form "+
-						"\"{,nb*}\" or \"{,nb[0-9]*}\", not %q.", expr)
-				}
-				if value != valueNoVar {
-					trace.Step1("Skipping checks for dependency pattern %q.", value)
-					return
-				}
-				for _, p := range expandCurlyBraces(mainValue) {
-					cv.WithValue(p + nbPart).DependencyPattern()
-				}
-				return
-			}
-		}
-	}
-
-	parser := NewMkParser(nil, value)
-	deppat := parser.DependencyPattern()
-	rest := parser.Rest()
-
-	if deppat != nil &&
-		(deppat.LowerOp != "" || deppat.UpperOp != "") &&
-		(rest == "{,nb*}" || rest == "{,nb[0-9]*}") {
-		cv.Warnf("Dependency patterns of the form pkgbase>=1.0 don't need the \"{,nb*}\" extension.")
-		cv.Explain(
-			"The \"{,nb*}\" extension is only necessary for dependencies of the",
-			"form \"pkgbase-1.2\", since the pattern \"pkgbase-1.2\" doesn't match",
-			"the version \"pkgbase-1.2nb5\".",
-			"For dependency patterns using the comparison operators,",
-			"this is not necessary.")
-
-	} else if deppat == nil || rest != "" {
-		if rest != "" && rest != value {
-			cv.Errorf("Dependency pattern %q is followed by extra text %q.",
-				value[:len(value)-len(rest)], rest)
-		} else {
-			cv.Errorf("Invalid dependency pattern %q.", value)
-		}
-		cv.Explain(
-			"Typical dependency patterns have the following forms:",
-			"",
-			"\tpackage>=2.5",
-			"\tpackage-[0-9]*",
-			"\tpackage-3.141",
-			"\tpackage>=2.71828<=3.1415")
-		return
-	}
-
-	wildcard := deppat.Wildcard
-	if m, inside := match1(wildcard, `^\[(.*)\]\*$`); m {
-		if inside != "0-9" {
-			cv.Warnf("Only \"[0-9]*\" is allowed as the numeric part of a dependency, not \"%s\".", wildcard)
-			cv.Explain(
-				"The pattern \"[0-9]*\" means any version.",
-				"All other version patterns should be expressed using the",
-				"comparison operators, such as <5.2.3 or >=1.0 or >=2<3.",
-				"",
-				"Patterns like \"[0-7]*\" only match the first digit of the",
-				"version number and will do the wrong thing when the package",
-				"reaches version 10.")
-		}
-
-	} else if m, ver, suffix := match2(wildcard, `^(\d\w*(?:\.\w+)*)(\.\*|\{,nb\*\}|\{,nb\[0-9\]\*\}|\*|)$`); m {
-		if suffix == "" {
-			cv.Warnf("Use %q instead of %q as the version pattern.", ver+"{,nb*}", ver)
-			cv.Explain(
-				"Without the \"{,nb*}\" suffix, this version pattern only matches",
-				"package versions that don't have a PKGREVISION (which is the part",
-				"after the \"nb\").")
-		}
-		if suffix == "*" {
-			cv.Warnf("Use %q instead of %q as the version pattern.", ver+".*", ver+"*")
-			cv.Explain(
-				"For example, the version \"1*\" also matches \"10.0.0\", which is",
-				"probably not intended.")
-		}
-
-	} else if wildcard == "*" {
-		cv.Warnf("Use \"%[1]s-[0-9]*\" instead of \"%[1]s-*\".", deppat.Pkgbase)
-		cv.Explain(
-			"If you use a * alone, the package specification may match other",
-			"packages that have the same prefix but a longer name.",
-			"For example, foo-* matches foo-1.2 but also",
-			"foo-client-1.2 and foo-server-1.2.")
-	}
-
-	withoutCharClasses := replaceAll(wildcard, `\[[\d-]+\]`, "")
-	if contains(withoutCharClasses, "-") {
-		cv.Warnf("The version pattern \"%s\" should not contain a hyphen.", wildcard)
-		cv.Explain(
-			"Pkgsrc interprets package names with version numbers like this:",
-			"",
-			"\t\"foo-2.0-2.1.x\" => pkgbase \"foo\", version \"2.0-2.1.x\"",
-			"",
-			"To make the \"2.0\" above part of the package basename, the hyphen",
-			"must be omitted, so the full package name becomes \"foo2.0-2.1.x\".")
-	}
-
-	checkDepends := func(
-		prefix string,
-		depends func(data *Buildlink3Data) *DependencyPattern,
-		dependsLine func(data *Buildlink3Data) *MkLine,
-	) {
-		if deppat.LowerOp == "" {
-			return
-		}
-		pkg := cv.MkLines.pkg
-		if pkg == nil {
-			return
-		}
-		if !hasPrefix(cv.Varname, prefix) {
-			return
-		}
-		bl3id := Buildlink3ID(varnameParam(cv.Varname))
-		data := pkg.bl3Data[bl3id]
-		if data == nil {
-			return
-		}
-		defpat := depends(data)
-		if defpat == nil || defpat.LowerOp == "" {
-			return
-		}
-		if containsExpr(defpat.Lower) || containsExpr(deppat.Lower) {
-			return
-		}
-		limit := condInt(defpat.LowerOp == ">=" && deppat.LowerOp == ">", 1, 0)
-		if pkgver.Compare(deppat.Lower, defpat.Lower) < limit {
-			cv.Notef("The requirement %s%s is already guaranteed by the %s%s from %s.",
-				deppat.LowerOp, deppat.Lower, defpat.LowerOp, defpat.Lower,
-				cv.MkLine.RelMkLine(dependsLine(data)))
-		}
-	}
-
-	checkDepends(
-		"BUILDLINK_API_DEPENDS.",
-		func(data *Buildlink3Data) *DependencyPattern { return data.apiDepends },
-		func(data *Buildlink3Data) *MkLine { return data.apiDependsLine },
-	)
-	checkDepends(
-		"BUILDLINK_ABI_DEPENDS.",
-		func(data *Buildlink3Data) *DependencyPattern { return data.abiDepends },
-		func(data *Buildlink3Data) *MkLine { return data.abiDependsLine })
-}
-
 func (cv *VartypeCheck) DependencyWithPath() {
 	value := cv.Value
 	valueNoVar := cv.ValueNoVar
@@ -471,9 +308,9 @@ func (cv *VartypeCheck) DependencyWithPath() {
 
 	parts := cv.MkLine.ValueSplit(value, ":")
 	if len(parts) != 2 {
-		cv.Errorf("Invalid dependency pattern with path %q.", value)
+		cv.Errorf("Invalid dependency pattern %q.", value)
 		cv.Explain(
-			"Examples for valid dependency patterns with path are:",
+			"Examples of valid dependency patterns are:",
 			"  package-[0-9]*:../../category/package",
 			"  package>=3.41:../../category/package",
 			"  package-2.718{,nb*}:../../category/package")
@@ -513,7 +350,7 @@ func (cv *VartypeCheck) DependencyWithPath() {
 		cv.Warnf("Use USE_TOOLS+=gmake instead of this dependency.")
 	}
 
-	cv.WithValue(pattern).DependencyPattern()
+	cv.WithValue(pattern).PackagePattern()
 }
 
 func (cv *VartypeCheck) DistSuffix() {
@@ -627,7 +464,16 @@ func (cv *VartypeCheck) FetchURL() {
 			continue
 		}
 
-		if G.Pkgsrc.MasterSiteVarToURL[name] == "" {
+		if name == "MASTER_SITE_BACKUP" {
+			if !cv.MkLine.HasRationale() {
+				cv.Warnf("The site MASTER_SITE_BACKUP should not be used.")
+				cv.Explain(
+					"MASTER_SITE_BACKUP is hosted by NetBSD",
+					"and is only for backup purposes.",
+					"Each package should have a primary MASTER_SITE",
+					"outside the NetBSD Foundation.")
+			}
+		} else if G.Pkgsrc.MasterSiteVarToURL[name] == "" {
 			if cv.MkLines.pkg == nil || !cv.MkLines.pkg.vars.IsDefined(name) {
 				cv.Errorf("The site %s does not exist.", name)
 			}
@@ -1026,6 +872,11 @@ func (cv *VartypeCheck) Option() {
 	}
 }
 
+func (cv *VartypeCheck) PackagePattern() {
+	ck := PackagePatternChecker{cv.Varname, cv.MkLine, cv.MkLines}
+	ck.Check(cv.Value, cv.ValueNoVar)
+}
+
 // Pathlist checks variables like the PATH environment variable.
 func (cv *VartypeCheck) Pathlist() {
 	value := cv.Value
@@ -1348,8 +1199,16 @@ func (cv *VartypeCheck) PackagePath() {
 		return
 	}
 
+	mustExist := true
+	if cv.Varname == "PATCHDIR" && cv.MkLines.pkg != nil {
+		distinfoFile := cv.MkLines.pkg.vars.LastValue("DISTINFO_FILE")
+		if distinfoFile != "" && NewPath(cv.Value).Dir() == NewPath(distinfoFile).Dir() {
+			mustExist = false
+		}
+	}
+
 	ck := MkLineChecker{cv.MkLines, cv.MkLine}
-	ck.CheckRelativePath(NewRelPathString(cv.Value), true)
+	ck.CheckRelativePath(NewRelPathString(cv.Value), mustExist)
 }
 
 func (cv *VartypeCheck) Restricted() {
@@ -1671,6 +1530,9 @@ func (cv *VartypeCheck) WrkdirSubdirectory() {
 	cv.Pathname()
 
 	if hasPrefix(cv.Value, "${WRKDIR}/") && cv.MkLines.pkg != nil {
+		if cv.MkLines.pkg.vars.IsDefined("GITHUB_TAG") {
+			return
+		}
 		distname := cv.MkLines.pkg.redundant.get("DISTNAME").vari
 		if distname.IsConstant() && cv.Value[10:] == distname.ConstantValue() {
 			fix := cv.Autofix()
@@ -1780,13 +1642,15 @@ func (cv *VartypeCheck) YesNo() {
 		case yes1, yes2, no1, no2:
 			break
 		default:
-			cv.Warnf("%s should be matched against %q or %q, not %q.", cv.Varname, yes1, no1, cv.Value)
+			cv.Warnf("%s should be matched against %q or %q, not %q.",
+				cv.Varname, yes1, no1, cv.Value)
 		}
 	} else if cv.Op == opUseCompare {
-		cv.Warnf("%s should be matched against %q or %q, not compared with %q.", cv.Varname, yes1, no1, cv.Value)
+		cv.Warnf("%s should be matched against %q or %q, not compared with %q.",
+			cv.Varname, yes1, no1, cv.Value)
 		cv.Explain(
-			"The yes/no value can be written in either upper or lower case, and",
-			"both forms are actually used.",
+			"The yes/no value can be written in either upper or lower case,",
+			"and both forms are actually used.",
 			"As long as this is the case, when checking the variable value,",
 			"both must be accepted.")
 	} else if !matches(cv.Value, `^(?:YES|yes|NO|no)$`) {
