@@ -377,301 +377,6 @@ func (s *Suite) Test_VartypeCheck_ConfFiles(c *check.C) {
 
 }
 
-// See Test_MkParser_DependencyPattern.
-func (s *Suite) Test_VartypeCheck_DependencyPattern(c *check.C) {
-	vt := NewVartypeCheckTester(s.Init(c), BtDependencyPattern)
-
-	vt.Varname("CONFLICTS")
-	vt.Op(opAssignAppend)
-
-	// numeric version comparison operators
-	vt.Values(
-		"perl5>=5.22",
-		"libkipi>=0.1.5<4.0",
-		"gtk2+>=2.16")
-	vt.OutputEmpty()
-
-	// textual pattern matching
-	vt.Values(
-		"perl-5*",
-		"perl5-*",
-		"perl-5.22",
-		"perl5-5.22.*",
-		"gtksourceview-sharp-2.0-[0-9]*",
-		"eboard-[0-9\\.]*")
-	vt.Output(
-		"WARN: filename.mk:11: Use \"5.*\" instead of \"5*\" as the version pattern.",
-		"WARN: filename.mk:12: Use \"perl5-[0-9]*\" instead of \"perl5-*\".",
-		"WARN: filename.mk:13: Use \"5.22{,nb*}\" instead of \"5.22\" as the version pattern.",
-		"WARN: filename.mk:15: The version pattern \"2.0-[0-9]*\" should not contain a hyphen.",
-		"WARN: filename.mk:16: Only \"[0-9]*\" is allowed as the numeric part of a dependency, not \"[0-9\\.]*\".",
-		"WARN: filename.mk:16: The version pattern \"[0-9\\.]*\" should not contain a hyphen.")
-
-	// nb suffix
-	vt.Values(
-		"perl5-5.22.*{,nb*}",
-		"perl-5.22{,nb*}",
-		"perl-5.22{,nb[0-9]*}",
-		"mbrola-301h{,nb[0-9]*}",
-		"ncurses-${NC_VERS}{,nb*}",
-		"gnome-control-center>=2.20.1{,nb*}",
-		"gnome-control-center>=2.20.1{,nb[0-9]*}")
-	vt.Output(
-		"WARN: filename.mk:26: Dependency patterns of the form pkgbase>=1.0 don't need the \"{,nb*}\" extension.",
-		"WARN: filename.mk:27: Dependency patterns of the form pkgbase>=1.0 don't need the \"{,nb*}\" extension.")
-
-	// alternative patterns, using braces or brackets
-	vt.Values(
-		"mpg123{,-esound,-nas}>=0.59.18",
-		"seamonkey-{,-bin,-gtk1}<2.0",
-		"mysql*-{client,server}-[0-9]*",
-		"{ssh{,6}-[0-9]*,openssh-[0-9]*}",
-		"libao-[a-z]*-[0-9]*")
-	vt.Output(
-		"ERROR: filename.mk:32: Invalid dependency pattern \"seamonkey-<2.0\".",
-		"ERROR: filename.mk:32: Invalid dependency pattern \"seamonkey--bin<2.0\".",
-		"ERROR: filename.mk:32: Invalid dependency pattern \"seamonkey--gtk1<2.0\".")
-
-	// expressions
-	vt.Values(
-		"postgresql8[0-35-9]-${module}-[0-9]*",
-		"${_EMACS_CONFLICTS.${_EMACS_FLAVOR}}",
-		"${PYPKGPREFIX}-sqlite3",
-		"${PYPKGPREFIX}-sqlite3-${VERSION}",
-		"${PYPKGPREFIX}-sqlite3-${PYSQLITE_REQD}",
-		"${PYPKGPREFIX}-sqlite3>=${PYSQLITE_REQD}",
-		"${EMACS_PACKAGE}>=${EMACS_MAJOR}",
-
-		// The "*" is ambiguous. It could either continue the PKGBASE or
-		// start the version number.
-		"${PKGNAME_NOREV:S/jdk/jre/}*",
-
-		// The canonical form is "{,nb*}" instead of "{nb*,}".
-		// Plus, mentioning nb* is not necessary when using >=.
-		"dovecot>=${PKGVERSION_NOREV}{nb*,}",
-
-		"oxygen-icons>=${KF5VER}{,nb[0-9]*}",
-
-		// The following pattern should have "]*}" instead of "]}*".
-		"ja-vflib-lib-${VFLIB_VERSION}{,nb[0-9]}*",
-
-		// The following pattern uses both ">=" and "*", which doesn't make sense.
-		"${PYPKGPREFIX}-sphinx>=1.2.3nb1*",
-
-		"{${NETSCAPE_PREFERRED:C/:/,/g}}-[0-9]*",
-
-		// These patterns are valid, assuming that DISTNAME is a valid PKGNAME.
-		"${DISTNAME}{,nb*}",
-		"${DISTNAME:S/-/-base-/}{,nb[0-9]*}",
-		"${RUBY_PKGPREFIX}-${DISTNAME}{,nb*}",
-
-		// A base version may have trailing version parts.
-		"atril>=${VERSION:R}.2")
-
-	vt.Output(
-		"ERROR: filename.mk:43: Invalid dependency pattern \"${PYPKGPREFIX}-sqlite3\".",
-		"ERROR: filename.mk:48: Invalid dependency pattern \"${PKGNAME_NOREV:S/jdk/jre/}*\".",
-		"WARN: filename.mk:49: The nb version part should have the form \"{,nb*}\" or \"{,nb[0-9]*}\", not \"{nb*,}\".",
-		"WARN: filename.mk:50: Dependency patterns of the form pkgbase>=1.0 don't need the \"{,nb*}\" extension.",
-		"WARN: filename.mk:51: The nb version part should have the form \"{,nb*}\" or \"{,nb[0-9]*}\", not \"{,nb[0-9]}\".",
-		"ERROR: filename.mk:52: Dependency pattern \"${PYPKGPREFIX}-sphinx>=1.2.3nb1\" is followed by extra text \"*\".")
-
-	// invalid dependency patterns
-	vt.Values(
-		"Perl",
-		"py-docs",
-		"perl5-[5.10-5.22]*",
-		"package-1.0|garbage",
-		"package>=1.0:../../category/package",
-		"package-1.0>=1.0.3",
-		// This should be regarded as invalid since the [a-z0-9] might either
-		// continue the PKGBASE or start the version number.
-		"${RUBY_PKGPREFIX}-theme-[a-z0-9]*",
-		"package>=2.9.0,<3",
-		"package>=2.16>=0")
-	vt.Output(
-		"ERROR: filename.mk:61: Invalid dependency pattern \"Perl\".",
-		"ERROR: filename.mk:62: Invalid dependency pattern \"py-docs\".",
-		"WARN: filename.mk:63: Only \"[0-9]*\" is allowed as the numeric part of a dependency, not \"[5.10-5.22]*\".",
-		"WARN: filename.mk:63: The version pattern \"[5.10-5.22]*\" should not contain a hyphen.",
-		"ERROR: filename.mk:64: Dependency pattern \"package-1.0\" is followed by extra text \"|garbage\".",
-		"ERROR: filename.mk:65: Dependency pattern \"package>=1.0\" is followed by extra text \":../../category/package\".",
-		// TODO: Mention that version numbers in a pkgbase must be appended directly, without hyphen.
-		"ERROR: filename.mk:66: Dependency pattern \"package-1.0\" is followed by extra text \">=1.0.3\".",
-		"ERROR: filename.mk:67: Invalid dependency pattern \"${RUBY_PKGPREFIX}-theme-[a-z0-9]*\".",
-		"ERROR: filename.mk:68: Dependency pattern \"package>=2.9.0\" is followed by extra text \",<3\".",
-		"ERROR: filename.mk:69: Dependency pattern \"package>=2.16\" is followed by extra text \">=0\".")
-}
-
-func (s *Suite) Test_VartypeCheck_DependencyPattern__smaller_version(c *check.C) {
-	t := s.Init(c)
-
-	t.SetUpPackage("category/package",
-		"LIB_VERSION_SMALL=\t1.0",
-		"LIB_VERSION_LARGE=\t10.0",
-		"",
-		".include \"../../category/lib/buildlink3.mk\"",
-		"BUILDLINK_API_DEPENDS.lib+=\tlib>=1.0pkg",
-		"BUILDLINK_API_DEPENDS.lib+=\tlib>=${LIB_VERSION_SMALL}",
-		"BUILDLINK_API_DEPENDS.lib+=\tlib>=${LIB_VERSION_LARGE}",
-		"BUILDLINK_ABI_DEPENDS.lib+=\tlib>=1.1pkg")
-	t.SetUpPackage("category/lib")
-	t.CreateFileBuildlink3("category/lib/buildlink3.mk",
-		"BUILDLINK_API_DEPENDS.lib+=\tlib>=1.3api",
-		"BUILDLINK_ABI_DEPENDS.lib+=\tlib>=1.4abi")
-	t.Chdir("category/package")
-	t.FinishSetUp()
-
-	G.checkdirPackage(".")
-
-	t.CheckOutputLines(
-		"NOTE: Makefile:24: The requirement >=1.0pkg is already guaranteed "+
-			"by the >=1.3api from ../../category/lib/buildlink3.mk:12.",
-		"ERROR: Makefile:27: Packages must only require API versions, "+
-			"not ABI versions of dependencies.",
-		"NOTE: Makefile:27: The requirement >=1.1pkg is already guaranteed "+
-			"by the >=1.4abi from ../../category/lib/buildlink3.mk:13.")
-}
-
-func (s *Suite) Test_VartypeCheck_DependencyPattern__different_operators(c *check.C) {
-	t := s.Init(c)
-
-	t.SetUpPackage("category/package",
-		".include \"../../category/lib/buildlink3.mk\"",
-		"BUILDLINK_API_DEPENDS.lib+=\tlib>=1.0pkg",
-		"BUILDLINK_ABI_DEPENDS.lib+=\tlib>=1.1pkg")
-	t.SetUpPackage("category/lib")
-	t.CreateFileBuildlink3("category/lib/buildlink3.mk",
-		"BUILDLINK_API_DEPENDS.lib+=\tlib>1.3api",
-		"BUILDLINK_ABI_DEPENDS.lib+=\tlib>1.4abi")
-	t.Chdir("category/package")
-	t.FinishSetUp()
-
-	G.checkdirPackage(".")
-
-	t.CheckOutputLines(
-		"NOTE: Makefile:21: The requirement >=1.0pkg is already guaranteed "+
-			"by the >1.3api from ../../category/lib/buildlink3.mk:12.",
-		"ERROR: Makefile:22: Packages must only require API versions, "+
-			"not ABI versions of dependencies.",
-		"NOTE: Makefile:22: The requirement >=1.1pkg is already guaranteed "+
-			"by the >1.4abi from ../../category/lib/buildlink3.mk:13.")
-}
-
-func (s *Suite) Test_VartypeCheck_DependencyPattern__additional_greater(c *check.C) {
-	t := s.Init(c)
-
-	t.SetUpPackage("category/package",
-		".include \"../../category/lib/buildlink3.mk\"",
-		"BUILDLINK_API_DEPENDS.lib+=\tlib>1.0pkg",
-		"BUILDLINK_ABI_DEPENDS.lib+=\tlib>1.1pkg")
-	t.SetUpPackage("category/lib")
-	t.CreateFileBuildlink3("category/lib/buildlink3.mk",
-		"BUILDLINK_API_DEPENDS.lib+=\tlib>=1.3api",
-		"BUILDLINK_ABI_DEPENDS.lib+=\tlib>=1.4abi")
-	t.Chdir("category/package")
-	t.FinishSetUp()
-
-	G.checkdirPackage(".")
-
-	t.CheckOutputLines(
-		"NOTE: Makefile:21: The requirement >1.0pkg is already guaranteed "+
-			"by the >=1.3api from ../../category/lib/buildlink3.mk:12.",
-		"ERROR: Makefile:22: Packages must only require API versions, "+
-			"not ABI versions of dependencies.",
-		"NOTE: Makefile:22: The requirement >1.1pkg is already guaranteed "+
-			"by the >=1.4abi from ../../category/lib/buildlink3.mk:13.")
-}
-
-func (s *Suite) Test_VartypeCheck_DependencyPattern__upper_limit(c *check.C) {
-	t := s.Init(c)
-
-	t.SetUpPackage("category/package",
-		".include \"../../category/lib/buildlink3.mk\"",
-		"BUILDLINK_API_DEPENDS.lib+=\tlib<2.0",
-		"BUILDLINK_ABI_DEPENDS.lib+=\tlib<2.1")
-	t.SetUpPackage("category/lib")
-	t.CreateFileBuildlink3("category/lib/buildlink3.mk",
-		"BUILDLINK_API_DEPENDS.lib+=\tlib>1.3api",
-		"BUILDLINK_ABI_DEPENDS.lib+=\tlib>1.4abi")
-	t.Chdir("category/package")
-	t.FinishSetUp()
-
-	G.checkdirPackage(".")
-
-	// If the additional constraint doesn't have a lower bound,
-	// there are no version numbers to compare and warn about.
-	t.CheckOutputLines(
-		"ERROR: Makefile:22: Packages must only require API versions, " +
-			"not ABI versions of dependencies.")
-}
-
-// Having an upper bound for a library dependency is unusual.
-// A combined lower and upper bound makes sense though.
-func (s *Suite) Test_VartypeCheck_DependencyPattern__upper_limit_in_buildlink3(c *check.C) {
-	t := s.Init(c)
-
-	t.SetUpPackage("category/package",
-		".include \"../../category/lib/buildlink3.mk\"",
-		"BUILDLINK_API_DEPENDS.lib+=\tlib>=16",
-		"BUILDLINK_ABI_DEPENDS.lib+=\tlib>=16.1")
-	t.SetUpPackage("category/lib")
-	t.CreateFileBuildlink3("category/lib/buildlink3.mk",
-		"BUILDLINK_API_DEPENDS.lib+=\tlib<7",
-		"BUILDLINK_ABI_DEPENDS.lib+=\tlib<6")
-	t.Chdir("category/package")
-	t.FinishSetUp()
-
-	G.checkdirPackage(".")
-
-	// If the additional constraint doesn't have a lower bound,
-	// there are no version numbers to compare and warn about.
-	t.CheckOutputLines(
-		"ERROR: Makefile:22: Packages must only require API versions, " +
-			"not ABI versions of dependencies.")
-}
-
-func (s *Suite) Test_VartypeCheck_DependencyPattern__API_ABI(c *check.C) {
-	t := s.Init(c)
-
-	t.SetUpPackage("category/package",
-		".include \"../../category/lib/buildlink3.mk\"",
-		"BUILDLINK_API_DEPENDS.lib+=\tlib>=1.0pkg",
-		".include \"../../category/indirect/buildlink3.mk\"",
-		"BUILDLINK_API_DEPENDS.indirect+=\tindirect>=${:U1.4api}")
-	t.SetUpPackage("category/lib")
-	t.CreateFileBuildlink3("category/lib/buildlink3.mk",
-		"BUILDLINK_ABI_DEPENDS.lib+=\tlib>=1.4abi")
-	t.CreateFileBuildlink3("category/indirect/buildlink3.mk",
-		"BUILDLINK_API_DEPENDS.indirect+=\tindirect>=${:U2.0}",
-		"BUILDLINK_ABI_DEPENDS.indirect+=\tindirect>=${:U2.2}")
-	t.Chdir("category/package")
-	t.FinishSetUp()
-
-	G.checkdirPackage(".")
-
-	t.CheckOutputEmpty()
-}
-
-func (s *Suite) Test_VartypeCheck_DependencyPattern__ABI_API(c *check.C) {
-	t := s.Init(c)
-
-	t.SetUpPackage("category/package",
-		".include \"../../category/lib/buildlink3.mk\"",
-		"BUILDLINK_ABI_DEPENDS.lib+=\tlib>=1.1pkg")
-	t.SetUpPackage("category/lib")
-	t.CreateFileBuildlink3("category/lib/buildlink3.mk",
-		"BUILDLINK_API_DEPENDS.lib+=\tlib>=1.3api")
-	t.Chdir("category/package")
-	t.FinishSetUp()
-
-	G.checkdirPackage(".")
-
-	t.CheckOutputLines(
-		"ERROR: Makefile:21: Packages must only require API versions, " +
-			"not ABI versions of dependencies.")
-}
-
 func (s *Suite) Test_VartypeCheck_DependencyWithPath(c *check.C) {
 	t := s.Init(c)
 
@@ -698,7 +403,7 @@ func (s *Suite) Test_VartypeCheck_DependencyWithPath(c *check.C) {
 		"gmake-[0-9]*:../../devel/gmake")
 
 	vt.Output(
-		"ERROR: ~/category/package/filename.mk:1: Invalid dependency pattern with path \"Perl\".",
+		"ERROR: ~/category/package/filename.mk:1: Invalid dependency pattern \"Perl\".",
 		"WARN: ~/category/package/filename.mk:2: Dependency paths should have the form \"../../category/package\".",
 		"ERROR: ~/category/package/filename.mk:2: Relative path \"../perl5/Makefile\" does not exist.",
 		"WARN: ~/category/package/filename.mk:2: \"../perl5\" is not a valid relative package directory.",
@@ -719,14 +424,14 @@ func (s *Suite) Test_VartypeCheck_DependencyWithPath(c *check.C) {
 		"broken>:../../x11/alacarte")      // incomplete comparison
 
 	vt.Output(
-		"ERROR: ~/category/package/filename.mk:11: Invalid dependency pattern \"broken0.12.1\".",
-		"ERROR: ~/category/package/filename.mk:12: Invalid dependency pattern \"broken[0-9]*\".",
-		"ERROR: ~/category/package/filename.mk:13: Invalid dependency pattern with path \"broken[0-9]*../../x11/alacarte\".",
-		"ERROR: ~/category/package/filename.mk:14: Invalid dependency pattern \"broken>=\".",
-		"ERROR: ~/category/package/filename.mk:15: Invalid dependency pattern \"broken=0\".",
-		"ERROR: ~/category/package/filename.mk:16: Invalid dependency pattern \"broken=\".",
-		"ERROR: ~/category/package/filename.mk:17: Invalid dependency pattern \"broken-\".",
-		"ERROR: ~/category/package/filename.mk:18: Invalid dependency pattern \"broken>\".")
+		"ERROR: ~/category/package/filename.mk:11: Invalid package pattern \"broken0.12.1\".",
+		"ERROR: ~/category/package/filename.mk:12: Invalid package pattern \"broken[0-9]*\".",
+		"ERROR: ~/category/package/filename.mk:13: Invalid dependency pattern \"broken[0-9]*../../x11/alacarte\".",
+		"ERROR: ~/category/package/filename.mk:14: Invalid package pattern \"broken>=\".",
+		"ERROR: ~/category/package/filename.mk:15: Invalid package pattern \"broken=0\".",
+		"ERROR: ~/category/package/filename.mk:16: Invalid package pattern \"broken=\".",
+		"ERROR: ~/category/package/filename.mk:17: Invalid package pattern \"broken-\".",
+		"ERROR: ~/category/package/filename.mk:18: Invalid package pattern \"broken>\".")
 
 	vt.Values(
 		"${PYPKGPREFIX}-sqlite3:../../${MY_PKGPATH.py-sqlite3}",
@@ -739,9 +444,9 @@ func (s *Suite) Test_VartypeCheck_DependencyWithPath(c *check.C) {
 
 	vt.Output(
 		"ERROR: ~/category/package/filename.mk:21: "+
-			"Invalid dependency pattern \"${PYPKGPREFIX}-sqlite3\".",
+			"Invalid package pattern \"${PYPKGPREFIX}-sqlite3\".",
 		"ERROR: ~/category/package/filename.mk:22: "+
-			"Invalid dependency pattern \"${PYPKGPREFIX}-sqlite3\".")
+			"Invalid package pattern \"${PYPKGPREFIX}-sqlite3\".")
 
 	vt.Values(
 		"gettext-[0-9]*:files/../../../databases/py-sqlite3")
@@ -795,7 +500,7 @@ func (s *Suite) Test_VartypeCheck_DependencyWithPath(c *check.C) {
 
 	vt.Output(
 		"ERROR: ~/category/package/filename.mk:71: " +
-			"Invalid dependency pattern with path \"py-sqlite3>=0:\".")
+			"Invalid dependency pattern \"py-sqlite3>=0:\".")
 }
 
 func (s *Suite) Test_VartypeCheck_DistSuffix(c *check.C) {
@@ -1049,6 +754,14 @@ func (s *Suite) Test_VartypeCheck_FetchURL(c *check.C) {
 	vt.Values("-https://github.com/org/proj/archive/v1.0.0.tar.gz")
 
 	vt.OutputEmpty()
+
+	vt.Varname("MASTER_SITES")
+	vt.Values(
+		"${MASTER_SITE_BACKUP}",
+		"${MASTER_SITE_BACKUP} # no alternative")
+
+	vt.Output(
+		"WARN: filename.mk:111: The site MASTER_SITE_BACKUP should not be used.")
 }
 
 func (s *Suite) Test_VartypeCheck_FetchURL__without_package(c *check.C) {
@@ -1624,6 +1337,14 @@ func (s *Suite) Test_VartypeCheck_Option(c *check.C) {
 			"Option names must start with a lowercase letter and be all-lowercase.")
 }
 
+func (s *Suite) Test_VartypeCheck_PackagePattern(c *check.C) {
+	t := s.Init(c)
+
+	// See Test_PackagePatternChecker_Check.
+
+	t.CheckOutputEmpty()
+}
+
 func (s *Suite) Test_VartypeCheck_Pathlist(c *check.C) {
 	vt := NewVartypeCheckTester(s.Init(c), BtPathlist)
 
@@ -2517,7 +2238,7 @@ func (s *Suite) Test_VartypeCheck_WrkdirSubdirectory(c *check.C) {
 		"NOTE: filename.mk:21: " +
 			"Setting WRKSRC to \"${WRKDIR}/package-1.0\" is redundant.")
 
-	// When the makefile is checked independent of a package, there
+	// When the makefile is checked independently of a package, there
 	// cannot be any redundancy check.
 	vt.Package(nil)
 
@@ -2726,8 +2447,9 @@ type VartypeCheckTester struct {
 	pkg       *Package
 }
 
-// NewVartypeCheckTester starts the test with a filename of "filename", at line 1,
-// with "=" as the operator. The variable has to be initialized explicitly.
+// NewVartypeCheckTester starts the test with a filename of "filename.mk",
+// at line 1, with "=" as the operator. The variable has to be initialized
+// explicitly.
 func NewVartypeCheckTester(t *Tester, basicType *BasicType) *VartypeCheckTester {
 
 	// This is necessary to know whether the variable name is a list type
